Fanova
======

Functional ANOVA: an implementation of the ICML 2014 paper "An Efficient Approach for Assessing Hyperparameter Importance" by Frank Hutter, Holger Hoos and Kevin Leyton-Brown.

Documentation
-------------

An 'ever growing' documentation for the Python bindings can be found at https://automl.github.io/fanova/
